@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2014 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2015 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 #
 # Python X2Go is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -670,9 +670,10 @@ class X2GoControlSession(paramiko.SSHClient):
         @rtype: C{bool}
 
         """
-        if self.remote_username() in self._x2go_remote_group('fuse'):
-            return True
-        return False
+        (stdin, stdout, stderr) = self._x2go_exec_command('which fusermount')
+
+        # if which returns the full path of fusermount, the current use is allowed to execute it
+        return bool(stdout.read())
 
     def remote_username(self):
         """\
@@ -872,6 +873,7 @@ class X2GoControlSession(paramiko.SSHClient):
         @raise X2GoSSHProxyException: any SSH proxy exception is passed through while establishing the SSH proxy connection and tunneling setup
         @raise X2GoSSHAuthenticationException: any SSH proxy authentication exception is passed through while establishing the SSH proxy connection and tunneling setup
         @raise X2GoRemoteHomeException: if the remote home directory does not exist or is not accessible
+        @raise X2GoControlSessionException: if the remote peer has died event unexpectedly
 
         """
         _fake_hostname = None
@@ -909,7 +911,7 @@ class X2GoControlSession(paramiko.SSHClient):
             pkey = None
 
         _twofactorauth = False
-        if password and (passphrase is None): passphrase = password
+        if password and (passphrase is None) and not force_password_auth: passphrase = password
 
         if use_sshproxy and sshproxy_host and sshproxy_user:
             try:
@@ -1015,7 +1017,7 @@ class X2GoControlSession(paramiko.SSHClient):
                                                            look_for_keys=False)
                             except TypeError:
                                 if _twofactorauth and password and passphrase and password != passphrase:
-                                    self.logger('your version of Paramiko/SSH does not support authentication workflows which require SSH key decryption in combination with two-factor authentication', loglevel=log.loglevel_WARNING)
+                                    self.logger('your version of Paramiko/SSH does not support authentication workflows which require SSH key decryption in combination with two-factor authentication', loglevel=log.loglevel_WARN)
                                 paramiko.SSHClient.connect(self, _hostname, port=port, username=username, password=password, pkey=pkey,
                                                            key_filename=key_filename, timeout=timeout, allow_agent=False,
                                                            look_for_keys=False)
@@ -1027,7 +1029,7 @@ class X2GoControlSession(paramiko.SSHClient):
                                                            look_for_keys=look_for_keys)
                             except TypeError:
                                 if _twofactorauth and password and passphrase and password != passphrase:
-                                    self.logger('your version of Paramiko/SSH does not support authentication workflows which require SSH key decryption in combination with two-factor authentication', loglevel=log.loglevel_WARNING)
+                                    self.logger('your version of Paramiko/SSH does not support authentication workflows which require SSH key decryption in combination with two-factor authentication', loglevel=log.loglevel_WARN)
                                 paramiko.SSHClient.connect(self, _hostname, port=port, username=username, password=password, pkey=None,
                                                            key_filename=None, timeout=timeout, allow_agent=allow_agent,
                                                            look_for_keys=look_for_keys)
@@ -1132,11 +1134,17 @@ class X2GoControlSession(paramiko.SSHClient):
             self.query_server_features(force=True)
             if self.forward_sshagent:
                 if x2go._paramiko.PARAMIKO_FEATURE['forward-ssh-agent']:
-                    self.agent_chan = ssh_transport.open_session()
-                    self.agent_handler = paramiko.agent.AgentRequestHandler(self.agent_chan)
-                    self.logger('Requesting SSH agent forwarding for control session of connected session profile %s' % self.profile_name, loglevel=log.loglevel_INFO)
+                    try:
+                        self.agent_chan = ssh_transport.open_session()
+                        self.agent_handler = paramiko.agent.AgentRequestHandler(self.agent_chan)
+                        self.logger('Requesting SSH agent forwarding for control session of connected session profile %s' % self.profile_name, loglevel=log.loglevel_INFO)
+                    except EOFError, e:
+                        # if we come across an EOFError here, we must assume the session is dead...
+                        self.session_died = True
+                        raise x2go_exceptions.X2GoControlSessionException('The SSH connection was dropped while setting up SSH agent forwarding socket.')
                 else:
                     self.logger('SSH agent forwarding is not available in the Paramiko version used with this instance of Python X2Go', loglevel=log.loglevel_WARN)
+
         else:
             self.close()
             if self.sshproxy_session:
