@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2014 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2015 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 #
 # Python X2Go is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -568,7 +568,7 @@ class X2GoTerminalSession(object):
                 ###
                 ### ARTSD AUDIO
                 ###
-                self.logger('the ArtsD sound server (as in KDE3) is obsolete and will not be supported by Python X2Go...', loglevel=log.loglevel_WARNING)
+                self.logger('the ArtsD sound server (as in KDE3) is obsolete and will not be supported by Python X2Go...', loglevel=log.loglevel_WARN)
 
             elif self.params.snd_system == 'esd':
                 ###
@@ -935,7 +935,11 @@ class X2GoTerminalSession(object):
 
             (stdin, stdout, stderr) = self.control_session._x2go_exec_command(cmd_line)
             _stdout = stdout.read().split('\n')
-            self.logger('x2gomountdirs output is: %s' % _stdout, log.loglevel_NOTICE)
+            if _stdout[0]:
+                self.logger('x2gomountdirs stdout is: %s' % _stdout, log.loglevel_NOTICE)
+            _stderr = stderr.read().split('\n')
+            if _stderr[0]:
+                self.logger('x2gomountdirs stderr is: %s' % _stderr, log.loglevel_WARN)
 
         except:
             self._share_local_folder_lock.release()
@@ -1487,8 +1491,11 @@ class X2GoTerminalSession(object):
                      str(setkbd),
                      str(self.params.session_type),
                      str(self.params.cmd),
-                     str(self.params.clipboard),
                    ]
+        if self.params.session_type != 'S':
+            cmd_line.append(
+                     str(self.params.clipboard),
+            )
 
         if self.params.cmd == 'XDMCP' and self.params.xdmcp_server:
             cmd_line = ['X2GOXDMCP=%s' % self.params.xdmcp_server] + cmd_line
